@@ -1,4 +1,3 @@
-// Paraselene generated this source file.
 package #1.#x;
 
 import paraselene.*;
@@ -19,7 +18,6 @@ paraselene.supervisor.PageFactory	pf = PageLoader.getPageFactory();
 pf.start();
 } catch( Exception e ) {
 Option.debug( e );
-e.printStackTrace();
 }
 }
 
