@@ -1,6 +1,7 @@
 package #1.#y#2;
 
 import paraselene.supervisor.*;
+import paraselene.dyna.*;
 
 /**
  * #3
@@ -49,5 +50,6 @@ public boolean isHistoryClear() { return false; }
  * @return 常にfalseを返す。
  */
 public boolean isAllowHistoryAdd() { return false; }
+public NameDefine[] inspectName( Page page, String ... exclude ){ return null;}
 }
 
