@@ -105,6 +105,17 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	 * @return エンコード後の文字列。
 	 */
 	public static String encode( String uri, String enc ) throws UnsupportedEncodingException {
+		return encode( uri, enc, false );
+	}
+
+	/**
+	 * URIのエンコード。
+	 * @param uri URI。
+	 * @param enc 文字コード。
+	 * @param xml_f true:&amp;のエスケープをする、false:しない。
+	 * @return エンコード後の文字列。
+	 */
+	public static String encode( String uri, String enc, boolean xml_f ) throws UnsupportedEncodingException {
 		uri = CSSURLStrip( uri );
 		if ( enc == null )	enc = DEFAULT_ENC;
 		String[]	frag = uri.split( "#" );
@@ -159,7 +170,7 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 			buf = buf.append( "?" );
 			String[]	param = query[1].split( "&" );
 			for ( int i = 0 ;i < param.length; i++ ) {
-				if ( i > 0 )	buf = buf.append( "&" );
+				if ( i > 0 )	buf = buf.append( xml_f?	WebChar._amp.getReference(): "&" );
 				String[]	data = param[i].split( "=" );
 				buf = buf.append( URLEncoder.encode( data[0], enc ) );
 				buf = buf.append( "=" );
@@ -223,7 +234,7 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 		else {
 			if ( dec == null )	dec = DEFAULT_ENC;
 			setText( URLDecoder.decode( u.toString(), dec ) );
-			feedback_f = super.toString( StringMode.PLAIN ).indexOf( Supervisor.LINK_DEF[0] ) == 0;
+			feedback_f = super.toString( StringMode.PLAIN ).indexOf( TransactionSequencer.LINK_DEF[0] ) == 0;
 		}
 	}
 
@@ -306,7 +317,7 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	 * @return URI。相対パスです。
 	 */
 	public static String pageToURI( PageID pid, String fragment, QueryItem ... query ) {
-		StringBuilder	buf = new StringBuilder( Supervisor.LINK_DEF[0] );
+		StringBuilder	buf = new StringBuilder( TransactionSequencer.LINK_DEF[0] );
 		buf = buf.append( pid.getID() );
 		if ( fragment != null ) {
 			buf = buf.append( "#" );
@@ -346,8 +357,8 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 	 * スキーマ。
 	 */
 	public enum Scheme {
-		HTTP( Supervisor.LINK_DEF[1], "http", 80 ),
-		HTTPS( Supervisor.LINK_DEF[2], "https", 443 );
+		HTTP( TransactionSequencer.LINK_DEF[1], "http", 80 ),
+		HTTPS( TransactionSequencer.LINK_DEF[2], "https", 443 );
 		private static final long serialVersionUID = 1L;
 		String	str;
 		String	prot;
@@ -467,26 +478,29 @@ public class URIValue extends PlainText implements AttributeValuable, CSSValuabl
 		out_enc = enc;
 	}
 
+	private static String toCSS( String uri ) {
+		if ( uri == null )	return null;
+		StringBuilder	buf = new StringBuilder( "url(" );
+		buf = buf.append( uri );
+		buf = buf.append( ")" );
+		return buf.toString();
+	}
+
 	public String toString( StringMode mode ) {
-		String	ret = null;
+		String	ret = super.toString( StringMode.PLAIN );
+		if ( mode == StringMode.PLAIN )	return ret;
 		try {
 			if ( paraselene.mockup.Linker.flag ) {
-				ret = URIValue.encode( super.toString( StringMode.PLAIN ), getCharset() );
+				ret = URIValue.encode( ret, getCharset() );
 			}
 			else {
-				ret = Supervisor.makeWithSessionURI( super.toString( StringMode.PLAIN ), getCharset(), getAssignedTag() );
+				ret = Supervisor.makeWithSessionURI( ret, getCharset(), getAssignedTag() );
 			}
 		}
 		catch( Exception e ){
 			Option.debug( e );
-			ret = super.toString( StringMode.PLAIN );
-		}
-		if ( ret != null && mode == StringMode.CSS ) {
-			StringBuilder	buf = new StringBuilder( "url(" );
-			buf = buf.append( ret );
-			buf = buf.append( ")" );
-			ret = buf.toString();
 		}
+		if ( mode == StringMode.CSS )	ret = toCSS( ret );
 		return ret;
 	}
 
