@@ -20,9 +20,9 @@ public class Version {
 	private Version(){}
 	/**
 	 * Paraseleneのバージョン番号を表す文字列。
-	 * 2.1.2.3
+	 * 2.2
 	 */
-	public static final String VERSION = "2.1.2.3";
+	public static final String VERSION = "2.2";
 	private static final String	SITE = " (http://paraselene.sourceforge.jp/)";
 	private static final String	TITLE = "Paraselene2 " + VERSION + SITE;
 	private static final String[] CLASS_PATH = new String[] {
@@ -116,6 +116,31 @@ public class Version {
 			buf = buf.append( "/" );
 			buf = buf.append( test[i] );
 		}
+		return seekTop( buf.toString() );
+	}
+
+	private static final String[] top_dir = new String[] {
+		"css", "image", "js"
+	};
+
+	private static String seekTop( String name ) {
+		String[]	dir = name.split( "/" );
+		int	top = dir.length - 1;
+		for ( ; top > 0; top-- ) {
+			boolean	flag = false;
+			for ( int i = 0; i < top_dir.length; i++ ) {
+				if ( dir[top].equals( top_dir[i] ) ) {
+					flag = true;
+					break;
+				}
+			}
+			if ( flag )	break;
+		}
+		StringBuilder	buf = new StringBuilder( dir[top] );
+		for ( top++; top < dir.length; top++ ) {
+			buf = buf.append( "/" );
+			buf = buf.append( dir[top] );
+		}
 		return buf.toString();
 	}
 
