@@ -74,6 +74,9 @@ public class Forward implements Serializable {
 	 * @param session_off true:セッションを解放する、false:セッションを維持する
 	 */
 	public Forward( PageID id, boolean history_use, boolean session_off ) {
+		if ( !(this instanceof Closure) && !(this instanceof Feedback) ) {
+			id = id.getPageFactory().getAjaxSurrogatePage( id );
+		}
 		out_page = id;
 		history_f = history_use;
 		session_clear_f = session_off;
@@ -103,7 +106,14 @@ public class Forward implements Serializable {
 		if ( af.length == 0 ) {
 			af = new AjaxForward[]{ new NOP() };
 		}
-		ajax = trim( af, SandBox.getCurrentRequestParameter().getHistory(), true );
+		ajax = af;
+		if ( SandBox.isCurrentDaemon() )	return;
+		initTrim( SandBox.getCurrentRequestParameter().getHistory() );
+	}
+
+	void initTrim( History hist ) {
+		if ( ajax == null )	return;
+		ajax = trim( ajax, hist, true );
 		not_ajax = getNotAjax();
 	}
 
@@ -262,5 +272,10 @@ public class Forward implements Serializable {
 		Option.trace( "new LocationOutput <- %s", this );
 		return new LocationOutput( nk, lp, this, r, sd );
 	}
+
+	CometCall makeCometCall( History h ) {
+		Option.trace( "new LocationCometCall <- %s", this );
+		return new LocationCometCall( h, this );
+	}
 }
 
