@@ -172,6 +172,24 @@ public class RequestParameter implements Serializable {
 	private Supervisor	supervisor = null;
 	static final String UA_HEAD = "User-Agent";
 
+	private static final String	AJAX_CALLED = "paraselene$ajax$called";
+	/**
+	 * フレームワークが使用します。
+	 */
+	public void markAjaxCalled() {
+		if ( session == null )	return;
+		session.setAttribute( AJAX_CALLED, new Boolean( true ) );
+	}
+
+	/**
+	 * クライアントが Ajax 通信を使用したか？
+	 * @return true:使用した痕跡がある、false:通信の痕跡がない。
+	 */
+	public boolean wasUsedAjax() {
+		if ( session == null )	return false;
+		return session.getAttribute( AJAX_CALLED ) != null;
+	}
+
 	/**
 	 * リクエスト内容の比較。
 	 * @param o 比較対象。
