@@ -48,11 +48,10 @@ public abstract class Supervisor extends HttpServlet {
 	 */
 	static final String SESSION_DATA = "paraselene$data";
 
-	public static final String[] LINK_DEF = new String[] {
-		"PARASELENE(PAGE)", "PARASELENE(HTTP)", "PARASELENE(HTTPS)"
-	};
 	private static final int[] LINK_LEN = new int[] {
-		LINK_DEF[0].length(), LINK_DEF[1].length(), LINK_DEF[2].length()
+		TransactionSequencer.LINK_DEF[0].length(),
+		TransactionSequencer.LINK_DEF[1].length(),
+		TransactionSequencer.LINK_DEF[2].length()
 	};
 	private static final String[] LINK_PROT = new String[] {
 		"", "http://", "https://"
@@ -74,11 +73,11 @@ public abstract class Supervisor extends HttpServlet {
 		super();
 	}
 
-	private static String resolvePage( DataHolder holder, PageID from_page, String p, int from_key, int to_key ) {
+	private static String resolvePage( ServerInformation holder, PageID from_page, String p, int from_key, int to_key ) {
 		try {
 			URI	u = new URI( p );
 			PageID	to = null;
-			Page	page = holder.sv.getPageFactory().getPage(
+			Page	page = from_page.getPageFactory().getPage(
 				Integer.parseInt( u.getPath().substring( LINK_LEN[0] ) )
 			);
 			if ( page != null ) {
@@ -89,8 +88,9 @@ public abstract class Supervisor extends HttpServlet {
 				StringBuilder	path = new StringBuilder(
 					TransactionSequencer.makeURI(
 						( page.isCheckRepeatSameRequest() )?
-							holder.data.seq: null,
-						from_page, to, from_key, to_key, !holder.search_engine
+							holder.getTransactionSequencer(): null,
+						from_page, to, from_key, to_key,
+						!holder.isSearchEngine()
 					)
 				);
 				String	query = u.getQuery();
@@ -113,16 +113,16 @@ public abstract class Supervisor extends HttpServlet {
 		}
 	}
 
-	private static String resolveHost( DataHolder holder, String path, int def_no ) {
+	private static String resolveHost( ServerInformation holder, String path, int def_no ) {
 		try {
 			int	port = Integer.parseInt( path.substring( LINK_LEN[def_no] ) );
 			StringBuilder	buf = new StringBuilder( LINK_PROT[def_no] );
-			buf = buf.append( holder.req.getServerName() );
+			buf = buf.append( holder.getServerName() );
 			if ( port > 0 && port < 0xffff ) {
 				buf = buf.append( ":" );
 				buf = buf.append( port );
 			}
-			buf = buf.append( holder.req.getContextPath() );
+			buf = buf.append( holder.getContextPath() );
 			return buf.toString();
 		}
 		catch( Exception e ) {
@@ -147,6 +147,36 @@ public abstract class Supervisor extends HttpServlet {
 		return ret;
 	}
 
+	static PageServerInformation getPageServerInformation() {
+		Page	page = SandBox.getCurrentPage();
+		if ( page != null ) {
+			PageServerInformation	psi = page.getPageServerInformation();
+			if ( psi != null )	return psi;
+		}
+		Supervisor	sv = null;
+		RequestParameter	req = SandBox.getCurrentRequestParameter();
+		if ( req != null ) {
+			sv = req.getSupervisor();
+		}
+		DataHolder	h = getDataHolder( sv );
+		if ( h == null )	return null;
+		return new PageServerInformation( h );
+	}
+
+	private static DataHolder getDataHolder( Supervisor sv ) {
+		synchronized( data_map_th ) {
+			if ( sv != null ) {
+				DataHolder	h = data_map_sv.get( sv );
+				if ( h != null )	return h;
+			}
+			return data_map_th.get( Thread.currentThread() );
+		}
+	}
+
+	private DataHolder getDataHolder() {
+		return getDataHolder( this );
+	}
+
 	/**
 	 * URIへのセッション情報付加。
 	 * @param uri URI。
@@ -154,17 +184,20 @@ public abstract class Supervisor extends HttpServlet {
 	 * @param tag タグ。
 	 * @return セッション情報が追加されたURI。
 	 */
-	public static String makeWithSessionURI( String uri, String enc, Tag tag ) 
-	throws UnsupportedEncodingException {
-		DataHolder	holder = null;
-		synchronized( data_map_th ) {
-			holder = data_map_th.get( Thread.currentThread() );
-		}
-		if ( holder == null )	return URIValue.encode( uri, enc );
-		int from_key, to_key;
+	public static String makeWithSessionURI( String uri, String enc, Tag tag ) throws UnsupportedEncodingException {
+		boolean	xml_f = false;
+		Page	page = null;
 		if ( tag != null ) {
-			from_key = tag.getAssignedPage().getHistoryKey();
-			to_key = holder.data.hist.toInt( getTarget( tag ), from_key );
+			page = tag.getAssignedPage();
+			xml_f = page.isXML();
+		}
+		ServerInformation	holder = getDataHolder( null );
+		if ( holder == null && page != null )	holder = page.getPageServerInformation();
+		if ( holder == null )	return URIValue.encode( uri, enc, xml_f );
+		int from_key, to_key;
+		if ( page != null ) {
+			from_key = page.getHistoryKey();
+			to_key = holder.getHistorySet().toInt( getTarget( tag ), from_key );
 		}
 		else	from_key = to_key = HistorySet.ROOT;
 		String[]	part = uri.split( "/" );
@@ -173,16 +206,16 @@ public abstract class Supervisor extends HttpServlet {
 		boolean	alias_f = false;
 		for ( int i = 0; i < part.length; i++ ) {
 			int	def_no;
-			for ( def_no = 0; def_no < LINK_DEF.length; def_no++ ) {
+			for ( def_no = 0; def_no < TransactionSequencer.LINK_DEF.length; def_no++ ) {
 				if ( part[i].length() < LINK_LEN[def_no] )	continue;
-				if ( LINK_DEF[def_no].equals( part[i].substring( 0, LINK_LEN[def_no] ) ) ){
+				if ( TransactionSequencer.LINK_DEF[def_no].equals( part[i].substring( 0, LINK_LEN[def_no] ) ) ){
 					flag = true;
 					break;
 				}
 			}
 			switch( def_no ) {
 			case 0:
-				part[i] = resolvePage( holder, tag.getAssignedPage().getID(), part[i], from_key, to_key );
+				part[i] = resolvePage( holder, page.getID(), part[i], from_key, to_key );
 				break;
 			case 1:
 			case 2:
@@ -198,10 +231,13 @@ public abstract class Supervisor extends HttpServlet {
 				buf = buf.append( part[i] );
 			}
 			uri = buf.toString();
-			uri = holder.response.encodeURL( URIValue.encode( uri, enc ) );
+			if ( holder instanceof DataHolder ) {
+				uri = ((DataHolder)holder).response.encodeURL( URIValue.encode( uri, enc, xml_f ) );
+			}
+			else	uri = URIValue.encode( uri, enc, xml_f );
 		}
 		else {
-			alias_f = holder.sv.getPageFactory().isAlias( uri );
+			alias_f = holder.getPageFactory().isAlias( uri );
 			if ( alias_f && to_key != HistorySet.ROOT ) {
 				StringBuilder	buf = new StringBuilder( TransactionSequencer.SELENE[5] );
 				buf = buf.append( "." );
@@ -212,11 +248,11 @@ public abstract class Supervisor extends HttpServlet {
 				buf = buf.append( uri );
 				uri = buf.toString();
 			}
-			if ( !alias_f && isMyHost( uri ) ) {
-				uri = holder.response.encodeURL( URIValue.encode( uri, enc ) );
+			if ( !alias_f && isMyHost( uri ) && holder instanceof DataHolder ) {
+				uri = ((DataHolder)holder).response.encodeURL( URIValue.encode( uri, enc, xml_f ) );
 			}
 			else {
-				uri = URIValue.encode( uri, enc );
+				uri = URIValue.encode( uri, enc, xml_f );
 			}
 		}
 		if ( head != null ) {
@@ -239,7 +275,7 @@ public abstract class Supervisor extends HttpServlet {
 			}
 			String	host = test.getHost();
 			if ( host == null )	return true;
-			if ( host.equals( holder.req.getServerName() ) )	return true;
+			if ( host.equals( holder.getServerName() ) )	return true;
 		}
 		catch( Exception e ){
 		}
@@ -247,10 +283,7 @@ public abstract class Supervisor extends HttpServlet {
 	}
 
 	static boolean isMyHost( String uri ) {
-		DataHolder	holder = null;
-		synchronized( data_map_th ) {
-			holder = data_map_th.get( Thread.currentThread() );
-		}
+		DataHolder	holder = getDataHolder( null );
 		return isMyHost( holder, uri );
 	}
 
@@ -260,20 +293,12 @@ public abstract class Supervisor extends HttpServlet {
 	 * @return true:自ホスト、false:他のホスト。
 	 */
 	public boolean isMyHostURI( String uri ) {
-		DataHolder	holder = null;
-		synchronized( data_map_th ) {
-			holder = data_map_th.get( Thread.currentThread() );
-			if ( holder == null )	holder = data_map_sv.get( this );
-		}
+		DataHolder	holder = getDataHolder();
 		return isMyHost( holder, uri );
 	}
 
 	static SessionData getSessionData( Supervisor sv ) {
-		DataHolder	holder = null;
-		synchronized( data_map_th ) {
-			holder = data_map_th.get( Thread.currentThread() );
-			if ( holder == null )	holder = data_map_sv.get( sv );
-		}
+		DataHolder	holder = getDataHolder( sv );
 		if ( holder == null )	return null;
 		return holder.data;
 	}
@@ -292,13 +317,9 @@ public abstract class Supervisor extends HttpServlet {
 	public abstract void onError( Throwable e );
 
 	private Forward onErrorDebug( Throwable e, HttpServletRequest req, HttpServletResponse res, int status ) {
-		if ( e instanceof Page.PageException ) {
-			Page.PageException	pe = (Page.PageException)e;
-			e = pe.get();
-		}
 		Forward fw = new Forward( status );
 		Option.debug( e );
-		onError( e );
+		if ( !(e instanceof SocketException) )	onError( e );
 		try {
 			fw.Action( this, res );
 		}
@@ -306,8 +327,10 @@ public abstract class Supervisor extends HttpServlet {
 			e2.printStackTrace();
 			onError( e2 );
 		}
-		HttpSession	session = req.getSession( false );
-		clear_session( session );
+		if ( !(e instanceof SocketException) ) {
+			HttpSession	session = req.getSession( false );
+			clear_session( session );
+		}
 		return fw;
 	}
 	private Forward onErrorDebug( Throwable e, HttpServletRequest req, HttpServletResponse res ) {
@@ -334,15 +357,11 @@ public abstract class Supervisor extends HttpServlet {
 	private void doAction( HttpServletRequest request, HttpServletResponse res ) {
 		HttpSession	session = null;
 		SessionData	data = null;
-		DataHolder	holder = null;
-		RequestParameter	req = null;
-		synchronized( data_map_th ) {
-			holder = data_map_th.get( Thread.currentThread() );
-			if ( holder == null )	holder = data_map_sv.get( this );
-			if ( holder != null ) {
-				data = holder.data;
-			}
+		DataHolder	holder = getDataHolder();
+		if ( holder != null ) {
+			data = holder.data;
 		}
+		RequestParameter	req = null;
 		try {
 			if ( data == null ) {
 				System.out.println( "SessionData null" );
@@ -363,7 +382,7 @@ public abstract class Supervisor extends HttpServlet {
 			if ( alias == null ) {
 				path_data = TransactionSequencer.parsePath( data.seq, uri, fact, data.hist );
 				if ( TransactionSequencer.isMustSession( uri ) ) {
-					if ( holder.search_engine ) {
+					if ( holder.isSearchEngine() ) {
 						new Forward( 403 ).Action( this, res );
 						clear_session( session );
 						return;
@@ -601,18 +620,14 @@ public abstract class Supervisor extends HttpServlet {
 	public static final String A_AJAX_KEY = "paraselene_a_ajax";
 
 	HttpSession makeNewSession( HttpSession old ) {
-		DataHolder	holder = null;
-		synchronized( data_map_th ) {
-			holder = data_map_th.get( Thread.currentThread() );
-			if ( holder == null )	holder = data_map_sv.get( this );
-		}
+		DataHolder	holder = getDataHolder();
 		if ( holder == null )	return old;
 		if ( old != null ) {
 			if ( holder.data != null )	holder.data.planed_clear = true;
 			clear_session( old );
 			if ( holder.data != null )	holder.data.planed_clear = false;
 		}
-		HttpSession	session = holder.req.getSession( true );
+		HttpSession	session = holder.getRequest().getSession( true );
 		session.setAttribute( SESSION_DATA, holder.data );
 		return session;
 	}
@@ -663,7 +678,7 @@ public abstract class Supervisor extends HttpServlet {
 			session = null;
 		}
 		else if ( session == null ) {
-			session = holder.req.getSession( true );
+			session = holder.getRequest().getSession( true );
 			session.setAttribute( SESSION_DATA, data );
 		}
 		if ( param.getMethod() == RequestParameter.Method.POST ) {
@@ -727,7 +742,7 @@ public abstract class Supervisor extends HttpServlet {
 					res.addCookie( fw.out_cookie.get( i ) );
 				}
 			}
-			if ( gzip( param, holder.req, res, out_ret[1], data, mime ) ) {
+			if ( gzip( param, holder.getRequest(), res, out_ret[1], data, mime ) ) {
 				data.hist.get( next_page.getHistoryKey() ).add( next_page );
 				return;
 			}
@@ -824,7 +839,7 @@ public abstract class Supervisor extends HttpServlet {
 		if ( !SandBox.isSafeFreeMemory() ) {
 			return new Forward( 503 );
 		}
-		DataHolder	holder = new DataHolder( this );
+		DataHolder	holder = new DataHolder( this, request );
 		HttpSession	session = request.getSession( false );
 		SessionData	data = null;
 		if ( session == null ) {
@@ -846,7 +861,6 @@ public abstract class Supervisor extends HttpServlet {
 				holder.session_null = true;
 			}
 		}
-		holder.req = request;
 		holder.response = res;
 		holder.data = data;
 
@@ -885,12 +899,8 @@ public abstract class Supervisor extends HttpServlet {
 		}
 		Option.appendTrace( log.toArray( new String[0] ) );
 
-/**** CACHE ******
-		Forward	ret = data.cacheResponse( req, res );
-		if ( ret != null )	return ret;
-******************/
 
-		holder.search_engine = req.judgeSearchEngine() != RequestParameter.SearchEngine.NO_SEARCHENGINE;
+		holder.setSearchEngine( req.judgeSearchEngine() != RequestParameter.SearchEngine.NO_SEARCHENGINE );
 		holder.request = req;
 
 		int	cnt = getRequestMaxCount();
@@ -928,9 +938,6 @@ public abstract class Supervisor extends HttpServlet {
 			onErrorDebug( e, req, res );
 		}
 		finally {
-/****** CACHE ************
-			cacheUnlock();
-*****************/
 			synchronized( data_map_th ) {
 				data_map_th.remove( Thread.currentThread() );
 				data_map_sv.remove( this );
@@ -951,9 +958,6 @@ public abstract class Supervisor extends HttpServlet {
 			onErrorDebug( e, req, res );
 		}
 		finally {
-/****** CACHE ************
-			cacheUnlock();
-*****************/
 			synchronized( data_map_th ) {
 				data_map_th.remove( Thread.currentThread() );
 				data_map_sv.remove( this );
@@ -961,22 +965,5 @@ public abstract class Supervisor extends HttpServlet {
 		}
 	}
 
-/******** CACHE ***********
-	private void cacheUnlock() {
-		SessionData	data = null;
-		DataHolder	holder = null;
-		RequestParameter	req = null;
-		synchronized( data_map_th ) {
-			holder = data_map_th.get( Thread.currentThread() );
-			if ( holder == null )	holder = data_map_sv.get( this );
-			if ( holder == null )	return;
-		}
-		data = holder.data;
-		if ( data == null )	return;
-		req = holder.request;
-		if ( req == null )	return;
-		data.cacheUnlock( req );
-	}
-*********************/
 }
 
