@@ -194,21 +194,21 @@ public class Attribute implements Serializable {
 	 * @return 属性値。無ければnull。
 	 */
 	public String getString() {
-		return getValueString();
+		return getValueString( HTMLPart.StringMode.PLAIN );
 	}
 
 	/**
 	 * 文字列生成。
 	 * @return 値を出力用に正規化したもの。
 	 */
-	protected String getValueString() {
+	protected String getValueString( HTMLPart.StringMode mode ) {
 		AttributeValuable[]	v = getAll();
 		if ( v == null )	return null;
 		if ( v.length < 1 )	return null;
-		StringBuilder	buf = new StringBuilder( v[0].toString( HTMLPart.StringMode.ATTRIBUTE ) );
+		StringBuilder	buf = new StringBuilder( v[0].toString( mode ) );
 		for ( int  i = 1; i < v.length; i++ ) {
 			buf = buf.append( "," );
-			buf = buf.append( v[i].toString( HTMLPart.StringMode.ATTRIBUTE ) );
+			buf = buf.append( v[i].toString( mode ) );
 		}
 		return buf.toString();
 	}
@@ -220,10 +220,11 @@ public class Attribute implements Serializable {
 	 */
 	public String toHtmlString( boolean xml ) {
 		StringBuilder	buf = new StringBuilder( name );
-		if ( getValueString() != null ) {
+		String	str = getValueString( HTMLPart.StringMode.ATTRIBUTE );
+		if ( str != null ) {
 			buf = buf.append( "=" );
 			buf = buf.append( "\"" );
-			buf = buf.append( getValueString() );
+			buf = buf.append( str );
 			buf = buf.append( "\"" );
 		}
 		else if ( xml ) {
