@@ -49,6 +49,7 @@ public class Tag extends HTMLPart {
 	private Page	embed_page = null_page;
 	private boolean	ajax_f = true;
 
+
 	/**
 	 * Ajax有効設定。初期値は true になっています。<br>
 	 * false を設定すると、Page が Ajax化されていても該当タグからは
@@ -81,8 +82,9 @@ public class Tag extends HTMLPart {
 		return embed_page;
 	}
 
+	private boolean modify_enable = true;
+
 	private void set_modify() {
-		//if ( "body".equals( name ) )	return;
 		if ( getAttribute( "id" ) == null ) {
 			Tag	out = getOuterTag();
 			if ( out != null ) {
@@ -93,7 +95,11 @@ public class Tag extends HTMLPart {
 		dirty_f = true;
 	}
 
+	/**
+	 * フレームワークが使用します。
+	 */
 	public void setModify() {
+		if ( !modify_enable )	return;
 		Tag	out = getOuterTag();
 		if ( out != null ) {
 			out.set_modify();
@@ -102,6 +108,20 @@ public class Tag extends HTMLPart {
 		set_modify();
 	}
 
+	/**
+	 * フレームワークが使用します。
+	 */
+	public void resetModify() {
+		dirty_f = false;
+	}
+
+	/**
+	 * フレームワークが使用します。
+	 */
+	public void setModifyEnable( boolean flag ) {
+		modify_enable = flag;
+	}
+
 	void getModifiedTag( ArrayList<Tag> list ) {
 		if ( dirty_f ) {
 			list.add( this );
@@ -363,6 +383,65 @@ public class Tag extends HTMLPart {
 		}
 	}
 
+	/**
+	 * 属性の追加/置換。<br>
+	 * setAttribute( new Attribute( n ) ) と等価です。
+	 * @param n 属性名。
+	 */
+	public void setAttribute( String n ) {
+		setAttribute( new Attribute( n ) );
+	}
+
+	/**
+	 * 属性の追加/置換。<br>
+	 * setAttribute( new Attribute( n, v ) ) と等価です。
+	 * @param n 属性名。
+	 * @param v 属性値。
+	 */
+	public void setAttribute( String n, BigDecimal v ) {
+		setAttribute( new Attribute( n, v ) );
+	}
+
+	/**
+	 * 属性の追加/置換。<br>
+	 * setAttribute( new Attribute( n, v ) ) と等価です。
+	 * @param n 属性名。
+	 * @param v 属性値。
+	 */
+	public void setAttribute( String n, double v ) {
+		setAttribute( new Attribute( n, v ) );
+	}
+
+	/**
+	 * 属性の追加/置換。<br>
+	 * setAttribute( new Attribute( n, v ) ) と等価です。
+	 * @param n 属性名。
+	 * @param v 属性値。
+	 */
+	public void setAttribute( String n, int v ) {
+		setAttribute( new Attribute( n, v ) );
+	}
+
+	/**
+	 * 属性の追加/置換。<br>
+	 * setAttribute( new Attribute( n, v ) ) と等価です。
+	 * @param n 属性名。
+	 * @param v 属性値。
+	 */
+	public void setAttribute( String n, String v ) {
+		setAttribute( new Attribute( n, v ) );
+	}
+
+	/**
+	 * 属性の追加/置換。<br>
+	 * setAttribute( new Attribute( n, v ) ) と等価です。
+	 * @param n 属性名。
+	 * @param v 属性値。
+	 */
+	public void setAttribute( String n, Valuable ... v ) {
+		setAttribute( new Attribute( n, v ) );
+	}
+
 	/**
 	 * 属性の削除。
 	 * @param at_name 属性名。
@@ -831,6 +910,7 @@ public class Tag extends HTMLPart {
 	public void write( PrintWriter w, StringMode mode ) {
 		dirty_f = false;
 		if ( !visible_f )	return;
+		w.print( "\r\n" );
 		w.print( getFirstTag() );
 		int	cnt = getHTMLPartCount();
 		if ( mode != StringMode.TEXTAREA )	mode = selectMode();
@@ -1185,6 +1265,7 @@ public class Tag extends HTMLPart {
 	 * </pre>のような文字列群です。各文字列には改行が追加されます。
 	 */
 	public void setAnonymousEventHandler( String triger, String ... function ) {
+		Page	page = getAssignedPage();
 		String	id = makeID();
 		StringBuilder	script = new StringBuilder();
 		for ( int i = 0; i < function.length; i++ ) {
@@ -1203,7 +1284,7 @@ public class Tag extends HTMLPart {
 		buf = buf.append( "=" );
 		buf = buf.append( script );
 		buf = buf.append( ";" );
-		getAssignedPage().addOnLoadScript( buf.toString() );
+		page.addOnLoadScript( buf.toString() );
 		setEventHandler( triger, ano );
 	}
 
