@@ -99,6 +99,10 @@ public class Button extends Input implements PageHooker, Clickable {
 	}
 
 	public void afterOutput( Page from, Page to, RequestParameter req ) throws Exception {
+		commitDaemon();
+	}
+
+	public void commitDaemon() {
 		StringBuilder	buf = new StringBuilder( "function(ev){" );
 		buf = buf.append( "paraselene_form_kill=" );
 		buf = buf.append( isAjaxEnable()?	"false":	"true" );
